==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/EncryptionConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.EncryptionConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Definition of CMK for the factory.
 * @property identity User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service Identity will be used.
 * @property keyName The name of the key in Azure Key Vault to use as Customer Managed Key.
 * @property keyVersion The version of the key used for CMK. If not provided, latest version will be used.
 * @property vaultBaseUrl The url of the Azure Key Vault used for CMK.
 */
public data class EncryptionConfigurationArgs(
    public val identity: Output<CMKIdentityDefinitionArgs>? = null,
    public val keyName: Output<String>,
    public val keyVersion: Output<String>? = null,
    public val vaultBaseUrl: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.EncryptionConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.EncryptionConfigurationArgs =
        com.pulumi.azurenative.datafactory.inputs.EncryptionConfigurationArgs.builder()
            .identity(identity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .keyName(keyName.applyValue({ args0 -> args0 }))
            .keyVersion(keyVersion?.applyValue({ args0 -> args0 }))
            .vaultBaseUrl(vaultBaseUrl.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EncryptionConfigurationArgs].
 */
@PulumiTagMarker
public class EncryptionConfigurationArgsBuilder internal constructor() {
    private var identity: Output<CMKIdentityDefinitionArgs>? = null

    private var keyName: Output<String>? = null

    private var keyVersion: Output<String>? = null

    private var vaultBaseUrl: Output<String>? = null

    /**
     * @param value User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service Identity will be used.
     */
    @JvmName("rkrqdgjwlbyqtejs")
    public suspend fun identity(`value`: Output<CMKIdentityDefinitionArgs>) {
        this.identity = value
    }

    /**
     * @param value The name of the key in Azure Key Vault to use as Customer Managed Key.
     */
    @JvmName("ddwuxiwgcbxqgokv")
    public suspend fun keyName(`value`: Output<String>) {
        this.keyName = value
    }

    /**
     * @param value The version of the key used for CMK. If not provided, latest version will be used.
     */
    @JvmName("geiasleuicbasjsm")
    public suspend fun keyVersion(`value`: Output<String>) {
        this.keyVersion = value
    }

    /**
     * @param value The url of the Azure Key Vault used for CMK.
     */
    @JvmName("wmxgoglcjrhurrmy")
    public suspend fun vaultBaseUrl(`value`: Output<String>) {
        this.vaultBaseUrl = value
    }

    /**
     * @param value User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service Identity will be used.
     */
    @JvmName("wcoscusddeohksnp")
    public suspend fun identity(`value`: CMKIdentityDefinitionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param argument User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service Identity will be used.
     */
    @JvmName("ydhhcqpfvsfasgpd")
    public suspend fun identity(argument: suspend CMKIdentityDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = CMKIdentityDefinitionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identity = mapped
    }

    /**
     * @param value The name of the key in Azure Key Vault to use as Customer Managed Key.
     */
    @JvmName("vmggfgwrqouiwkbj")
    public suspend fun keyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyName = mapped
    }

    /**
     * @param value The version of the key used for CMK. If not provided, latest version will be used.
     */
    @JvmName("nmdcwnlftxiwkick")
    public suspend fun keyVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVersion = mapped
    }

    /**
     * @param value The url of the Azure Key Vault used for CMK.
     */
    @JvmName("wkrrqmjbfnnlabqa")
    public suspend fun vaultBaseUrl(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vaultBaseUrl = mapped
    }

    internal fun build(): EncryptionConfigurationArgs = EncryptionConfigurationArgs(
        identity = identity,
        keyName = keyName ?: throw PulumiNullFieldException("keyName"),
        keyVersion = keyVersion,
        vaultBaseUrl = vaultBaseUrl ?: throw PulumiNullFieldException("vaultBaseUrl"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/EncryptionConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.EncryptionConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Definition of CMK for the factory.
 * @property identity User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service Identity will be used.
 * @property keyName The name of the key in Azure Key Vault to use as Customer Managed Key.
 * @property keyVersion The version of the key used for CMK. If not provided, latest version will be used.
 * @property vaultBaseUrl The url of the Azure Key Vault used for CMK.
 */
public data class EncryptionConfigurationArgs(
    public val identity: Output<CMKIdentityDefinitionArgs>? = null,
    public val keyName: Output<String>,
    public val keyVersion: Output<String>? = null,
    public val vaultBaseUrl: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.EncryptionConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.EncryptionConfigurationArgs =
        com.pulumi.azurenative.datafactory.inputs.EncryptionConfigurationArgs.builder()
            .identity(identity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .keyName(keyName.applyValue({ args0 -> args0 }))
            .keyVersion(keyVersion?.applyValue({ args0 -> args0 }))
            .vaultBaseUrl(vaultBaseUrl.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EncryptionConfigurationArgs].
 */
@PulumiTagMarker
public class EncryptionConfigurationArgsBuilder internal constructor() {
    private var identity: Output<CMKIdentityDefinitionArgs>? = null

    private var keyName: Output<String>? = null

    private var keyVersion: Output<String>? = null

    private var vaultBaseUrl: Output<String>? = null

    /**
     * @param value User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service Identity will be used.
     */
    @JvmName("kftcoqbksqqpgwag")
    public suspend fun identity(`value`: Output<CMKIdentityDefinitionArgs>) {
        this.identity = value
    }

    /**
     * @param value The name of the key in Azure Key Vault to use as Customer Managed Key.
     */
    @JvmName("ravpjhvwjcpeevvv")
    public suspend fun keyName(`value`: Output<String>) {
        this.keyName = value
    }

    /**
     * @param value The version of the key used for CMK. If not provided, latest version will be used.
     */
    @JvmName("gqepfjttchwnyfbi")
    public suspend fun keyVersion(`value`: Output<String>) {
        this.keyVersion = value
    }

    /**
     * @param value The url of the Azure Key Vault used for CMK.
     */
    @JvmName("ijiwtfkmexpriija")
    public suspend fun vaultBaseUrl(`value`: Output<String>) {
        this.vaultBaseUrl = value
    }

    /**
     * @param value User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service Identity will be used.
     */
    @JvmName("aqekjedgfedhtqxn")
    public suspend fun identity(`value`: CMKIdentityDefinitionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param argument User assigned identity to use to authenticate to customer's key vault. If not provided Managed Service Identity will be used.
     */
    @JvmName("saujbcdyedxhqvrn")
    public suspend fun identity(argument: suspend CMKIdentityDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = CMKIdentityDefinitionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identity = mapped
    }

    /**
     * @param value The name of the key in Azure Key Vault to use as Customer Managed Key.
     */
    @JvmName("aqattedrvqjxjmvg")
    public suspend fun keyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyName = mapped
    }

    /**
     * @param value The version of the key used for CMK. If not provided, latest version will be used.
     */
    @JvmName("lihmfmwfbhsogsmp")
    public suspend fun keyVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVersion = mapped
    }

    /**
     * @param value The url of the Azure Key Vault used for CMK.
     */
    @JvmName("cnwosclrxfwatsec")
    public suspend fun vaultBaseUrl(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vaultBaseUrl = mapped
    }

    internal fun build(): EncryptionConfigurationArgs = EncryptionConfigurationArgs(
        identity = identity,
        keyName = keyName ?: throw PulumiNullFieldException("keyName"),
        keyVersion = keyVersion,
        vaultBaseUrl = vaultBaseUrl ?: throw PulumiNullFieldException("vaultBaseUrl"),
    )
}
